<?php

if (!defined('BASEPATH')) {
    exit('No direct script access allowed');
}

class MODULE_site extends MX_Controller
{

    public function index()
    {
        $content = array();

        return $this->parser->parse('MODULE/template', $content, TRUE);
    }

}
