<?php

class ccc_active implements crud_callback_chunk
{
    public function get_name()
    {
        return 'Checkbox with buttons';
    }
    
    public function get_options()
    {
        return FALSE;
    }
    
    public function get_schema()
    {
        return 'tinyint(1)';
    }

    public function run()
    {
        return '\'active\'';
    }
}
