<?php

if (!defined('BASEPATH')) {
    exit('No direct script access allowed');
}

/**
 * Upgrade MODULE module to version TO_VERSION
 *
 * @author CIEXT skeleton
 */
class MODULE_upgrade_FILE_VERSION extends Abstract_upgrade
{

    public function up()
    {
        return 'TO_VERSION';
    }
    
    public function down()
    {
        return 'FROM_VERSION';
    }

}
